Split

Trait Split 

pub trait Split<const LO: usize> {
    type Output: Integer;
}
Define the result of splitting a number into two parts, with the first part having the width LO.

Required Associated Types

type Output: Integer

High limbs of output: having the width of Self minus LO.

Implementors

Source

impl Split<{ <$name>::LIMBS / 2 }> for U128

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U256

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U384

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U512

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U640

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U768

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U896

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U1280

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U1536

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U1792

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U2048

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U3072

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U3584

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U4096

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U4224

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U4352

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U6144

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U8192

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ <$name>::LIMBS / 2 }> for U16384

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl Split<{ U64::LIMBS * $size }> for U192

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U192

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U256

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U256

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U320

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U320

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U320

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U320

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U384

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U384

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U384

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U384

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U448

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U448

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U448

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U448

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U448

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U448

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U512

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U512

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U512

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U512

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U512

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U512

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U576

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U576

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U576

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U576

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U576

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U576

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U576

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U576

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U640

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U640

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U640

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U640

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U640

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U640

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U640

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U640

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U704

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U704

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U704

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U704

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U704

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U704

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U704

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U704

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U704

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U704

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U768

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U768

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U768

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U768

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U768

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U768

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U768

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U768

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U768

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U768

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U832

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U896

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U960

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>

Source

impl Split<{ U64::LIMBS * $size }> for U1024

Source

type Output = Uint<{ <$name>::LIMBS - U64::LIMBS * $size }>