pub trait Split<const LO: usize> {
type Output: Integer;
}Expand description
Define the result of splitting a number into two parts, with the
first part having the width LO.
pub trait Split<const LO: usize> {
type Output: Integer;
}Define the result of splitting a number into two parts, with the
first part having the width LO.